@@ -3,7 +3,7 @@ package String::ShortenHostname::App;
 use Moose;
 use IO::Handle;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 extends 'String::ShortenHostname';
 with 'MooseX::Getopt';
@@ -27,6 +27,12 @@ has '+domain_edge' => (
 	documentation => "edge string for truncation of domain",
 );
 
+has '+cut_middle' => (
+	traits => ['Getopt'],
+	cmd_aliases => "m",
+	documentation => "dont truncate, cut in the middle of domain",
+);
+
 has '+force' => (
 	traits => ['Getopt'],
 	cmd_aliases => "f",
